package
Version:
v0.1.3
Opens a new window with list of versions in this module.
Published: Jul 2, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Result struct {
Engine string `json:"engine"`
Notes []domain.Note `json:"notes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.